@@ -69,7 +69,8 @@ grep 'maude3__EXEEXT__OBJECTS' Makefile.in && exit 1
 
 ./configure
 
-run_make -O EXEEXT=.foo print
+EXEEXT=.foo $MAKE -e print > stdout
+cat stdout
 
 grep '1BEG: maude.foo mt.foo :END1' stdout
 grep '2BEG: maude.static.foo :END2' stdout
@@ -78,7 +79,8 @@ grep '4BEG: rmt.foo :END4' stdout
 
 ./configure revert=yes
 
-run_make -O EXEEXT=.foo print
+EXEEXT=.foo $MAKE -e print > stdout
+cat stdout
 
 grep '1BEG: maude.foo :END1' stdout
 grep '2BEG: maude.static.foo :END2' stdout
