@@ -27,7 +27,6 @@ AC_OUTPUT
 END
 
 cat >Makefile.am <<'END'
-AUTOMAKE_OPTIONS = subdir-objects
 nobase_lib_LTLIBRARIES = liba1.la sub/liba2.la sub/liba3.la liba4.la liba5.la
 sub_liba2_la_LIBADD = liba1.la
 sub_liba3_la_LIBADD = sub/liba2.la
@@ -53,7 +52,8 @@ $AUTOMAKE --add-missing
 ./configure --prefix="$(pwd)/inst"
 
 $MAKE
-run_make -E install
+$MAKE install 2>stderr || { cat stderr >&2; exit 1; }
+cat stderr >&2
 grep 'has not been installed' stderr && exit 1
 
 $MAKE uninstall
