@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2012 Free Software Foundation, Inc.
+# Copyright (C) 2011-2013 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # - empty TESTS
 # - empty TEST_LOGS
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_CONFIG_FILES([sub1/Makefile sub2/Makefile])
@@ -62,7 +62,7 @@ $AUTOMAKE -a
 
 no_test_has_run ()
 {
-  ls -1 *.log | grep -v '^test-suite\.log$' | grep . && Exit 1
+  ls -1 *.log | grep -v '^test-suite\.log$' | grep . && exit 1
   grep '^# TOTAL: *0$' test-suite.log
   :
 }
